/// <reference types="bn.js" />
import { PublicKey } from "@solana/web3.js";
import { TransactionBuilder } from "@orca-so/common-sdk";
import { ConfigOptionParams, EscrowConfigData, EscrowContext, KycCertData, PDA, TokenInfoData } from "..";
import { BN } from "@project-serum/anchor";
export declare class EscrowConfigClient {
    ctx: EscrowContext;
    publicKey: PublicKey;
    data: EscrowConfigData;
    pda: PDA;
    constructor(ctx: EscrowContext, publicKey: PublicKey, pda: PDA, data: EscrowConfigData);
    static getConfig(ctx: EscrowContext, configId: string | PublicKey): Promise<EscrowConfigClient>;
    setTradeConfigAuthority(deployerPubkey: PublicKey, newTradeConfigAuthority: PublicKey): Promise<TransactionBuilder>;
    setAmlPolicyAuthority(deployerPubkey: PublicKey, newAmlPolicyAuthority: PublicKey): Promise<TransactionBuilder>;
    addArbitratorCert(tradeConfigAuthority: PublicKey, arbitratorAuthority: PublicKey): Promise<TransactionBuilder>;
    addToken(tradeConfigAuthority: PublicKey, tokenMint: PublicKey, quota30Days: BN[], quota24Hours: BN[]): Promise<TransactionBuilder>;
    removeToken(tradeConfigAuthority: PublicKey, tokenMint: PublicKey): Promise<TransactionBuilder>;
    setRenecRate(tradeConfigAuthority: PublicKey, tokenMint: PublicKey, renecRate: BN): Promise<TransactionBuilder>;
    setMinmumOfferAmount(tradeConfigAuthority: PublicKey, tokenMint: PublicKey, minimumOfferAmount: BN): Promise<TransactionBuilder>;
    removeArbitratorCert(tradeConfigAuthority: PublicKey, arbitratorAuthority: PublicKey): Promise<TransactionBuilder>;
    updateConfig(tradeConfigAuthority: PublicKey, option: ConfigOptionParams): Promise<TransactionBuilder>;
    setKycCert(amlPolicyAuthority: PublicKey, tokenMint: PublicKey, user: PublicKey, level: number): Promise<TransactionBuilder>;
    getKycCert(tokenMint: PublicKey, user: PublicKey): Promise<KycCertData>;
    getTokenInfo(user: PublicKey): Promise<TokenInfoData>;
    isArbitrator(arbitratorAuthority: PublicKey): Promise<boolean>;
    refresh(): Promise<EscrowConfigClient>;
}
