import { Connection, PublicKey } from "@solana/web3.js";
import { Address } from "@project-serum/anchor";
import { ArbitratorCert, EscrowConfigData, KycCertData, OfferData, TokenInfoData, TradeData } from "../";
import { ParsableEntity } from "./parsing";
/**
 * Supported accounts
 */
export type CachedValue = EscrowConfigData | TradeData | KycCertData | ArbitratorCert | OfferData;
/**
 * Include both the entity (i.e. type) of the stored value, and the value itself
 */
export interface CachedContent<T extends CachedValue> {
    entity: ParsableEntity<T>;
    value: CachedValue | null;
}
export declare class AccountFetcher {
    private readonly connection;
    private readonly _cache;
    private _tokenAccountRentExempt;
    constructor(connection: Connection, cache?: Record<string, CachedContent<CachedValue>>);
    /*** Public Methods ***/
    /**
     * Retrieve minimum balance for rent exemption of a Token Account;
     *
     * @param refresh force refresh of account rent exemption
     * @returns minimum balance for rent exemption
     */
    getTokenAccountRentExempt(refresh?: boolean): Promise<number>;
    getEscrowConfig(address: Address, refresh?: boolean): Promise<EscrowConfigData | null>;
    getTradeData(address: Address, refresh?: boolean): Promise<TradeData | null>;
    getOfferData(address: Address, refresh?: boolean): Promise<OfferData | null>;
    getKycCertData(address: Address, refresh?: boolean): Promise<KycCertData | null>;
    getArbitratorCertData(address: Address, refresh?: boolean): Promise<ArbitratorCert | null>;
    getTradeDatas(addresses: PublicKey[], refresh?: boolean): Promise<(TradeData | null)[]>;
    getOfferDatas(addresses: PublicKey[], refresh?: boolean): Promise<(OfferData | null)[]>;
    getTokenInfoData(address: PublicKey, refresh?: boolean): Promise<TokenInfoData | null>;
    /**
     * Update the cached value of all entities currently in the cache.
     * Uses batched rpc request for network efficient fetch.
     */
    refreshAll(): Promise<void>;
    /*** Private Methods ***/
    /**
     * Retrieve from cache or fetch from rpc, an account
     */
    private get;
    /**
     * Retrieve from cache or fetch from rpc, a list of accounts
     */
    private list;
    /**
     * Make batch rpc request
     */
    private bulkRequest;
}
